@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.13'
+__version__ = '0.1.14'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -243,6 +243,8 @@ HELP_ID_PREFIX_STATE = 'help_app_state#'                            #: message i
 IGNORED_HELP_FLOWS = (id_of_flow('close', 'flow_popup'), )          #: tuple of flow ids never search/show help text for
 IGNORED_HELP_STATES = ('flow_id', 'flow_path', 'win_rectangle')     #: tuple of app state names never searched help for
 
+HIDDEN_GLOBALS = ('__builtins__', '__doc__', 'module_globals')      #: globals that get removed from help_variables
+
 
 def anchor_points(radius: float, anchor_x: float, anchor_y: float, anchor_dir: str) -> Tuple[float, ...]:
     """ recalculate points of the anchor triangle drawing.
@@ -537,8 +539,8 @@ class HelpAppBase(MainAppBase, ABC):
         :param help_vars:       initial help variable locals that will be extended and returned.
         :return:                global and local variable dicts.
         """
-        glo_vars = module_globals.copy()
-        glo_vars.update(globals())
+        glo_vars = {k: v for k, v in module_globals.items() if k not in HIDDEN_GLOBALS}
+        glo_vars.update((k, v) for k, v in globals().items() if k not in HIDDEN_GLOBALS)
         glo_vars['_add_base_globals'] = True        # instruct ae.inspector.try_eval to add ae.core globals
 
         help_vars['app'] = self.framework_app
